@@ -130,11 +130,20 @@ class TamingDecoder(ImageGenerator):
     def get_img_from_latents(
         self,
         z_logits: torch.Tensor,
+        target_img_height: int = None,
+        target_img_width: int = None,
     ):
         z = self.vqgan_model.post_quant_conv(z_logits)
         img_rec = self.vqgan_model.decoder(z)
         img_rec = (img_rec.clip(-1, 1) + 1) / 2
 
+        if target_img_height is not None and target_img_width is not None:
+            img_rec = torch.nn.functional.interpolate(
+                img_rec,
+                (target_img_height, target_img_width),
+                mode="bilinear",
+            )
+
         return img_rec
 
     @staticmethod
@@ -149,8 +158,8 @@ class TamingDecoder(ImageGenerator):
         z_logits = .5 * torch.randn(
             batch_size,
             256,
-            embed_width,
             embed_height,
+            embed_width,
         )
 
         z_logits = torch.sinh(1.9 * torch.arcsinh(z_logits))
@@ -178,7 +187,8 @@ class TamingDecoder(ImageGenerator):
         self,
         prompt: str,
         lr: float = 0.5,
-        target_img_size: int = 256,
+        target_img_height: int = 256,
+        target_img_width: int = 256,
         num_steps: int = 200,
         num_augmentations: int = 32,
         init_img_path: str = None,
@@ -249,8 +259,8 @@ class TamingDecoder(ImageGenerator):
 
         else:
             z_logits = self.get_random_latents(
-                target_img_height=target_img_size,
-                target_img_width=target_img_size,
+                target_img_height=target_img_height,
+                target_img_width=target_img_width,
                 batch_size=batch_size,
             ).to(self.device)
 
@@ -270,12 +280,17 @@ class TamingDecoder(ImageGenerator):
 
             z_logits_list.append(z_logits.detach().clone())
 
-            rec_img = self.get_img_from_latents(z_logits)
+            rec_img = self.get_img_from_latents(
+                z_logits,
+                target_img_height=target_img_height,
+                target_img_width=target_img_width,
+            )
+
             x_rec_stacked = self.augment(
                 rec_img,
                 num_crops=num_augmentations,
-                target_img_width=target_img_size,
-                target_img_height=target_img_size,
+                target_img_width=target_img_width,
+                target_img_height=target_img_height,
             )
 
             clip_loss = 10 * self.compute_clip_loss(
@@ -463,7 +478,8 @@ class TamingDecoder(ImageGenerator):
 
 
 if __name__ == '__main__':
-    target_img_size = 256
+    target_img_height = 50
+    target_img_width = 400
     prompt = "A pink dog"
     lr = 0.5
     num_steps = 200
@@ -491,7 +507,8 @@ if __name__ == '__main__':
         gen_img_list, z_logits_list = taming_decoder.generate_from_prompt(
             prompt=prompt,
             lr=lr,
-            target_img_size=target_img_size,
+            target_img_height=target_img_height,
+            target_img_width=target_img_width,
             num_steps=num_steps,
             num_augmentations=num_augmentations,
             init_img_path=init_img_path,
